@@ -9,10 +9,11 @@
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
-#
-# import os
-# import sys
-# sys.path.insert(0, os.path.abspath('.'))
+
+import os
+import sys
+
+sys.path.insert(0, os.path.abspath("./extensions"))
 
 
 # -- Project information -----------------------------------------------------
@@ -22,7 +23,7 @@ copyright = "2021, Joe Rickerby"
 author = "Joe Rickerby"
 
 # The full version, including alpha/beta/rc tags
-release = "5.1.1"
+release = "5.1.2"
 
 
 # -- General configuration ---------------------------------------------------
@@ -30,7 +31,12 @@ release = "5.1.1"
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
-extensions = ["myst_parser", "sphinx.ext.autodoc", "sphinxcontrib.programoutput"]
+extensions = [
+    "myst_parser",
+    "sphinx.ext.autodoc",
+    "sphinxcontrib.programoutput",
+    "signature_change",
+]
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
